==> icons-vue-0.3.0.tgz: package/lib/watson-health/thumbnail-preview/16.js <==
'use strict';

var __chunk_1 = require('../../chunk-d2faeea1.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthThumbnailPreview16 = {
  name: 'WatsonHealthThumbnailPreview16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(__chunk_1._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = __chunk_1._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = __chunk_1._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16 23a4 4 0 1 1 4-4A4.0042 4.0042 0 0 1 16 23zm0-6a2 2 0 1 0 2 2A2.0023 2.0023 0 0 0 16 17zM30 4V8a2.0027 2.0027 0 0 1-2 2H24a2.0027 2.0027 0 0 1-2-2V4a2.0027 2.0027 0 0 1 2-2h4A2.0027 2.0027 0 0 1 30 4zM28 8l.002-4H24V8zM20 4V8a2.0027 2.0027 0 0 1-2 2H14a2.0023 2.0023 0 0 1-2-2V4a2.0023 2.0023 0 0 1 2-2h4A2.0027 2.0027 0 0 1 20 4zM18 8l.002-4H14V8zM10 4V8a2.0023 2.0023 0 0 1-2 2H4A2.0023 2.0023 0 0 1 2 8V4A2.0023 2.0023 0 0 1 4 2H8A2.0023 2.0023 0 0 1 10 4zM8 8l.0015-4H4V8z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthThumbnailPreview16;

==> icons-vue-0.6.0.tgz: package/lib/watson-health/thumbnail-preview/16.js <==
'use strict';

var _rollupPluginBabelHelpers = require('../../_rollupPluginBabelHelpers-00d81fcb.js');
var iconHelpers = require('@rocketsoftware/icon-helpers');

var virtual_WatsonHealthThumbnailPreview16 = {
  name: 'WatsonHealthThumbnailPreview16',
  functional: true,
  // We use title as the prop name as it is not a valid attribute for an SVG
  // HTML element
  props: ['title'],
  render: function render(createElement, context) {
    var children = context.children,
        data = context.data,
        listeners = context.listeners,
        props = context.props;
    var attrs = iconHelpers.getAttributes(_rollupPluginBabelHelpers._objectSpread2({
      width: '16',
      height: '16',
      viewBox: '0 0 32 32',
      preserveAspectRatio: 'xMidYMid meet',
      xmlns: 'http://www.w3.org/2000/svg',
      // Special case here, we need to coordinate that we are using title,
      // potentially, to get the right focus attributes
      title: props.title
    }, data.attrs));
    var svgData = {
      attrs: attrs,
      on: listeners
    };

    if (data.staticClass) {
      svgData.class = _rollupPluginBabelHelpers._defineProperty({}, data.staticClass, true);
    }

    if (data.class) {
      svgData.class = svgData.class || {}; // may be no static class

      svgData.class[data.class] = true;
    } // remove style set by getAttributes


    delete svgData.attrs.style; // combine incoming staticStyle, style with default willChange

    svgData.style = _rollupPluginBabelHelpers._objectSpread2({
      willChange: 'transform'
    }, data.staticStyle, {}, data.style);
    return createElement('svg', svgData, [props.title && createElement('title', null, props.title), createElement('path', {
      attrs: {
        "d": "M28,12H4a2.0023,2.0023,0,0,0-2,2V28a2.002,2.002,0,0,0,2,2H28a2.0023,2.0023,0,0,0,2-2V14A2.0027,2.0027,0,0,0,28,12ZM20,28H12V27a1.0009,1.0009,0,0,1,1-1h6a1.0009,1.0009,0,0,1,1,1Zm8,0H22V27a3.0033,3.0033,0,0,0-3-3H13a3.0033,3.0033,0,0,0-3,3v1H4V14H28.002Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M16,23a4,4,0,1,1,4-4A4.0042,4.0042,0,0,1,16,23Zm0-6a2,2,0,1,0,2,2A2.0023,2.0023,0,0,0,16,17Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M30,4V8a2.0027,2.0027,0,0,1-2,2H24a2.0027,2.0027,0,0,1-2-2V4a2.0027,2.0027,0,0,1,2-2h4A2.0027,2.0027,0,0,1,30,4ZM28,8l.002-4H24V8Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M20,4V8a2.0027,2.0027,0,0,1-2,2H14a2.0023,2.0023,0,0,1-2-2V4a2.0023,2.0023,0,0,1,2-2h4A2.0027,2.0027,0,0,1,20,4ZM18,8l.002-4H14V8Z"
      }
    }), createElement('path', {
      attrs: {
        "d": "M10,4V8a2.0023,2.0023,0,0,1-2,2H4A2.0023,2.0023,0,0,1,2,8V4A2.0023,2.0023,0,0,1,4,2H8A2.0023,2.0023,0,0,1,10,4ZM8,8l.0015-4H4V8Z"
      }
    }), children]);
  }
};

module.exports = virtual_WatsonHealthThumbnailPreview16;
